@@ -56,8 +56,10 @@ Creates object on the server. E.g.
     
 sub post {
     my $class = shift;
-    my $connection = shift || die "no connection";
-    my $data = shift || die "no data";
+    my $connection = shift;
+    my $data = shift;
+    die 'usage: '.$class.'->post($connection, $data)'
+	unless $connection && $data && $connection->can('POST');
     my %opt = @_;
     my $json = $class->_freeze($data);
     my $path = $opt{path} || $class->path
@@ -104,10 +106,12 @@ Fetches one or more objects from the server.
 
 sub get {
     my $self = shift;
-    my $connection = shift || die "no connection";
-    my $query_data = shift || die "no data";
+    my $connection = shift;
+    my $query_data = shift;
     my %opt = @_;
     my $class = ref($self) || $self;
+    die 'usage: '.$class.'->get($connection, $query_data)'
+	unless $connection && $query_data && $connection->can('GET');
 
     my $path = $opt{path};
     $path ||= $query_data->{id}
@@ -122,22 +126,22 @@ sub get {
 	: $class->construct($msg, connection => $connection, parent => $opt{parent});
 }
 
-=head2 del
+=head2 delete
 
 Deletes an object from the server
 
-    $session->del;
+    $session->delete;
 
 =cut
 
-sub del {
+sub delete {
     my $self = shift;
     my $connection = shift
 	|| $self->connection
 	|| die 'Not connected';
     my $data = shift || {id => $self->id};
     my $path = $self->resource;
-    $connection->DEL($path, $data);
+    $connection->DELETE($path, $data);
 }
 
 =head2 find_or_create
@@ -192,12 +196,17 @@ Computes a RESTful resource path for the object.
 
 sub path {
     my $self = shift;
+    my %opt = @_;
+    my $parent = $opt{parent};
+    $parent ||= $self->parent
+	if ref($self);
     my $path = '';
-    $path .= $self->parent->path . '/'
-	if ref($self) && $self->parent;
+    $path .= $parent->path . '/'
+	if $parent;
     $path .= $self->resource;
     my $id = ref $self && $self->id;
-    $id ? $path . '/' . $id : $path;
+    $path .= '/' . $id if $id;
+    $path;
 }
 
 =head2 parent
@@ -382,7 +391,8 @@ sub _thaw {
 		if defined $val;
 	}
 	else {
-	    warn "ignoring field: $fld";
+	    my $class = ref($self) || $self;
+	    warn $class." ignoring field: $fld";
 	}
     }
     \%thawed;
