@@ -37,9 +37,56 @@ This class is used to manage Sessions (Virtual Classrooms).
 	    },
 	);
 
+=head2 Enrolling User in Sessions
+
+AFAIK, there are two classes and two different modes for enrolling user to sessions:
+
+=over 4
+
+=item (*)  Ad-hoc users via L<Bb::Collaborate::Ultra::LaunchContext>
+
+    my $user = Bb::Collaborate::Ultra::User->new({
+	extId => 'testLaunchUser',
+	displayName => 'David Warring',
+	email => 'david.warring@gmail.com',
+	firstName => 'David',
+	lastName => 'Warring',
+    });
+
+    my $launch_context = Bb::Collaborate::Ultra::LaunchContext->new({ launchingRole => 'moderator',
+	 editingPermission => 'writer',
+	 user => $user,
+	 });
+
+    my $join_url = $launch_context->join_session($session);
+
+=item (*) Permanently managed users via L<Bb::Collaborate::Ultra::LaunchContext>
+
+Each user is created once.
+
+    my $ultra_user = Bb::Collaborate::Ultra::User->create($connection, {
+	extId => 'testLaunchUser',
+	displayName => 'David Warring',
+	email => 'david.warring@gmail.com',
+	firstName => 'David',
+	lastName => 'Warring',
+    });
+    my $ultra_user_id = $ultra_user->id;
+    # somehow save the user id permanently...
+
+The saved user-id may then be used to multiple times to join sessions:
+
+     my $enrollment =  Bb::Collaborate::Ultra::Session::Enrollment->new({ launchingRole => 'moderator',
+	 editingPermission => 'writer',
+	 userId => $user2->id,
+	 });
+      my $join_url = $enrolment->enrol($session)->permanentUrl;
+
+=back
+
 =head1 METHODS
 
-See L<https://xx-csa.bbcollab.com/documentation#Session>
+This class supports the `get`, `post`, `patch` and `del` methods as described in L<https://xx-csa.bbcollab.com/documentation#Session>
 
 =cut
 
@@ -62,14 +109,16 @@ __PACKAGE__->query_params(
     startTime => 'Date',
     endTime => 'Date',
     sessionCategory => 'Str',
-);
-
-use Bb::Collaborate::Ultra::LaunchContext;
-use Bb::Collaborate::Ultra::SessionEnrollment;
+    );
 
 =head2 enrollments
 
-Return a list of users who are enrolled for the session.
+Return a list of users, of type L<Bb::Collaborate::Ultra::Session::Enrollment>.
+
+    my @enrollments = $session->enrollments;
+    for my $enrolment (@enrollments) {
+        say "user @{[$enrolment->userId]} is enrolled as a @{[$enrollment->launchingRole]}";
+    }
 
 =cut
 
@@ -78,7 +127,22 @@ sub enrollments {
     my $data = shift;
     my $connection = shift || $self->connection;
     my $path = $self->path.'/enrollments';
-    Bb::Collaborate::Ultra::SessionEnrollment->get($connection => {}, path => $path, parent => $self);
+    require Bb::Collaborate::Ultra::Session::Enrollment;
+    Bb::Collaborate::Ultra::Session::Enrollment->get($connection => {}, path => $path, parent => $self);
+}
+
+=head2 logs
+
+Returns logging information for completed sessions
+
+=cut
+
+sub logs {
+    my $self = shift;
+    my $connection = shift || $self->connection;
+    my $path = $self->path.'/instances';
+    require Bb::Collaborate::Ultra::Session::Log;
+    Bb::Collaborate::Ultra::Session::Log->get($connection => {}, path => $path, parent => $self);
 }
 
 1;
@@ -263,6 +327,9 @@ __DATA__
     },
     "canShareAudio" : {
       "type" : "boolean"
+    },
+    "anonymizeRecording" : {
+      "type" : "boolean"
     }
   }
 }
